<?php

namespace Modules\Pars\Entities;

use Exception;
use Illuminate\Database\Eloquent\Model;
use Symfony\Component\DomCrawler;
use Symfony\Component\DomCrawler\Crawler;

class Category extends Model
{
    protected $table = 'pars_categories';
    protected $fillable = [];


    // проверка на сучествование категории с таким же url
    static public function existCategory($url)
    {
        $category = Category::where('url', $url)->first();
        return (!$category) ? false : true;
    }

    static public function parsCategories()
    {
        $url = 'https://5element.by/catalog';
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // возвращает результат в переменную а не в буфер
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true); //использовать редиректы
        curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 6.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.90 Safari/537.36'); //выставляем настройки браузера
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // работа с https
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false); // работа с https
        curl_setopt($ch, CURLOPT_POST, 1);
        $html = curl_exec($ch);

        $crawler = new DomCrawler\Crawler($html);

        $res = $crawler->filter('li.catalog-prod-col-item')->each(function (Crawler $node, $i) {
            return ['name' => trim($node->text()),
                'url' => $node->filter('a')->attr('href')];
        });
        return $res;
    }


    public function extractFromHtml($html)
    {
        $crawler = new DomCrawler\Crawler($html);

        $id = trim($crawler->filter('.product-link')->eq(2)->attr('data-id'));
        $brand = trim($crawler->filter('.product-link')->eq(2)->attr('data-brand'));
        $category = trim($crawler->filter('.product-link')->eq(2)->attr('data-category'));
        $name = trim($crawler->filter('.product-link')->eq(2)->attr('data-name'));
        $price = trim($crawler->filter('.product-link')->eq(2)->attr('data-price'));

        return [
            'brand' => $brand,
            'category' => $category,
            'id' => $id,
            'name' => $name,
            'price' => $price
        ];
    }


    static public function parsProducts()
    {
        $categoryId = 24505;
        $currentPage = 1;
        $itemsPerPage = 20;
        $postData = array('categoryId' => (int)$categoryId,
            'currentPage' => (int)$currentPage,
            'itemsPerPage' => (int)$itemsPerPage,
            'viewType' => 1,
            'sortName' => 'popular',
            'sortDest' => 'desc',
            'filterInStock' => 1,
            'filterInStore' => 0);
        $url = 'https://5element.by/ajax/catalog_category_list.php?SECTION_ID=0';
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // возвращает результат в переменную а не в буфер
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true); //использовать редиректы
        //   curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36'); //выставляем настройки браузера
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // работа с https
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false); // работа с https
        $html = curl_exec($ch);
        curl_close($ch);
        return json_decode($html);
    }

    static public function inactiveCategory($id)
    {
        $category = Category::find($id);
        $category->active = 0;
        $category->save();
    }

    static public function activeCategory($id)
    {
        $category = Category::find($id);
        $category->active = 1;
        $category->save();
    }

    static public function getCategoryDesc($categoryId)
    {
        $postData = array('categoryId' => (int)$categoryId,
            'currentPage' => 1,
            'itemsPerPage' => 10,
            'viewType' => 1,
            'sortName' => 'popular',
            'sortDest' => 'desc',
            'filterInStock' => 1,
            'filterInStore' => 0);
        $url = 'https://5element.by/ajax/catalog_category_list.php?SECTION_ID=' . $categoryId;
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // возвращает результат в переменную а не в буфер
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true); //использовать редиректы
        //   curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36'); //выставляем настройки браузера
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // работа с https
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false); // работа с https
        $html = curl_exec($ch);
        $html = json_decode($html);

        if ($html->updateSection!=''){
        try {
            $ds['ID_INPUT'] = $categoryId;
            $ds['ID'] = $html->updateSection->section->ID;
            $ds['UF_IB_RELATED_ID'] = $html->updateSection->section->UF_IB_RELATED_ID;
            $ds['NAME'] = $html->updateSection->section->NAME;
            $ds['SEO_NAME'] = $html->updateSection->section->SEO_NAME;
            $ds['DETAIL_URL'] = $html->updateSection->section->DETAIL_URL;
            $ds['DETAIL_PICTURE'] = $html->updateSection->section->DETAIL_PICTURE;
            $ds['DATE_CREATE'] = $html->updateSection->section->DATE_CREATE;
            $ds['COUNT'] = $html->count;
        } catch (Exception $e) {
            echo 'Ошибка при парсинге категорий: category_id='.$categoryId.'  '.$e->getMessage();
        } finally {
            return $ds;
        }}

    }
}
